@@ -401,20 +401,20 @@ class KodexaPlatform:
     @staticmethod
     def __build_object(ref, object_type_metadata, object_class):
         from kodexa import KodexaPlatform
-        url = f"{KodexaPlatform.get_url()}/api/{object_type_metadata.plural}/{ref.replace(':', '/')}"
+        url = f"{KodexaPlatform.get_url()}/api/{object_type_metadata['plural']}/{ref.replace(':', '/')}"
 
         import requests
         response = requests.get(url,
                                 headers={"x-access-token": KodexaPlatform.get_access_token(),
                                          "content-type": "application/json"})
 
-        return object_class.parse_obj(response.json())
+        return object_class(**response.json())
 
     @staticmethod
     def get_object_instance(ref: str, object_type):
         object_type, object_type_metadata = resolve_object_type(object_type)
 
-        if object_type_metadata['type'] is Taxonomy:
+        if 'type' in object_type_metadata and object_type_metadata['type'] is Taxonomy:
             return KodexaPlatform.__build_object(ref, object_type_metadata, Taxonomy)
 
         if object_type == 'stores':
@@ -1212,6 +1212,8 @@ class EventHelper:
                 if content_object.store_ref is not None:
                     context.document_store = KodexaPlatform.get_object_instance(content_object.store_ref, 'store')
 
+                return input_document
+
 
 class SessionConnector:
     event_helper = None
